fn note(out: &mut Vec<Violation>, path: &str, kind: ViolationKind)Expand description
Pushes a violation unless the report is already at MAX_VIOLATIONS.
fn note(out: &mut Vec<Violation>, path: &str, kind: ViolationKind)Pushes a violation unless the report is already at MAX_VIOLATIONS.